@@ -7,7 +7,7 @@ use base qw( CatalystX::CRUD::Object );
 use Rose::DB::Object::Helpers qw( column_values_as_json );
 use JSON;
 
-our $VERSION = '0.30';
+our $VERSION = '0.301';
 
 =head1 NAME
 
@@ -141,6 +141,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing List
+
+L<https://groups.google.com/forum/#!forum/catalystxcrud>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/CatalystX-CRUD-Model-RDBO>
